@@ -146,6 +146,7 @@ int conf_var::current_config_file_line_no_ = 0;
 			"verbosity",
 			"wordfilesmax",
 			"wordpercentmax",
+			"wordthreshold",
 #ifdef	SEARCH_DAEMON
 			"group",
 			"pidfile",
@@ -252,6 +253,7 @@ int conf_var::current_config_file_line_no_ = 0;
 			<< file_name << "\"\n";
 		::exit( Exit_Config_File );
 	}
+	conf_file.behavior( mmap_file::sequential );
 
 	register int line_no = 0;
 	register mmap_file::const_iterator c = conf_file.begin();
