@@ -27,6 +27,9 @@
 // standard
 #include <vector>
 
+// local
+#include "encoded_char.h"
+
 //*****************************************************************************
 //
 // SYNOPSIS
@@ -81,7 +84,7 @@
 	// the index.
 	//
 	off_t const orig_file_size = file_size();
-#endif
+#endif	/* INDEX */
 
 #ifndef	PJL_NO_SYMBOLIC_LINKS
 	if ( is_symbolic_link( file_name ) && !follow_symbolic_links ) {
@@ -94,7 +97,7 @@
 			cout << " (skipped: symbolic link)\n";
 		return;
 	}
-#endif
+#endif	/* PJL_NO_SYMBOLIC_LINKS */
 
 #ifdef	INDEX
 	//
@@ -106,7 +109,7 @@
 			cout << " (skipped: encountered before)\n";
 		return;
 	}
-#endif
+#endif	/* INDEX */
 
 	////////// Perform filter name substitution(s) ////////////////////////
 
@@ -172,6 +175,14 @@
 		// We're not running as a filter: check to see if the extracted
 		// file already exists; if so, skip extraction entirely.
 		//
+		if ( ::strlen( file_name ) + extract_extension.length()
+			> PATH_MAX
+		) {
+			if ( verbosity > 3 )
+				cout	<< " (skipped: " << extract_extension
+					<< " file-name too long)\n";
+			return;
+		}
 		char extracted_file_name[ PATH_MAX + 1 ];
 		::strcpy( extracted_file_name, file_name );
 		::strcat( extracted_file_name, extract_extension );
@@ -189,8 +200,9 @@
 					<< extract_extension << " file)\n";
 			return;
 		}
+		out = &extracted_file;
 	}
-#endif
+#endif	/* EXTRACT */
 
 	//
 	// Execute the filter(s) on the file.
@@ -211,6 +223,7 @@
 			cout << " (skipped: can not open)\n";
 		return;
 	}
+	file.behavior( mmap_file::sequential );
 
 	if ( verbosity == 3 )			// print base name of file
 		cout << "  " << orig_base_name << flush;
@@ -227,8 +240,11 @@
 
 	////////// Index the file /////////////////////////////////////////////
 
-	static indexer *const text = indexer::find_indexer( "text" );
-	indexer *const i = found_pattern ? include_pattern->second : text;
+#ifdef	IMPLEMENT_DECODING
+	encoded_char_range::decoder::reset_all();
+#endif
+	indexer *const i = found_pattern ?
+		include_pattern->second : indexer::text_indexer();
 	file_info *const fi = new file_info(
 		orig_file_name, dir_index, orig_file_size, i->find_title( file )
 	);
@@ -237,14 +253,14 @@
 	if ( verbosity > 2 )
 		cout << " (" << fi->num_words() << " words)\n";
 
-	if ( words.size() >= Word_Threshold )
+	if ( words.size() >= word_threshold )
 		write_partial_index();
-#endif
+#endif	/* INDEX */
 
 #ifdef	EXTRACT
 	////////// Extract the file ///////////////////////////////////////////
 
 	++num_extracted_files;
 	extract_words( file.begin(), file.end(), *out );
-#endif
+#endif	/* EXTRACT */
 }
