@@ -296,7 +296,7 @@
 		// C++ has become overly pedantic about casting to enums.
 		//
 		element::end_tag_value const
-			v = (element::end_tag_value const)(int const)(p[1]);
+			v = (element::end_tag_value const)(long const)(p[1]);
 		element &e = insert(
 			value_type( *p++, element( v ) )
 		).first->second;
