@@ -52,7 +52,7 @@ namespace PJL {
 //*****************************************************************************
 {
 public:
-	bool contains( T const &s ) const { return find( s ) != end(); }
+	bool contains( T const &s ) const { return find( s ) != this->end(); }
 };
 
 //*****************************************************************************
